@@ -42,7 +42,7 @@ import rmdSelect as isel
 import rmdTrayPopup as iTP
 import rmdMonitor as imon
 import os,signal,popen2,fcntl
-
+from rmdStrings import *
 #values struct:
 
 #0   fps
@@ -65,31 +65,6 @@ import os,signal,popen2,fcntl
 
 
 class trayIcon(object):
-    #values=[15,0,0,1,os.path.join(os.getenv('HOME'),'out.ogg'),[-1,-1,-1,-1],0,
-            #1,22050,'hw:0,0',63,10,"$DISPLAY",0,1,75,1]
-    exit_status={
-        0:_('Success'),
-        1*256:_('Error while parsing the arguments.'),
-        2*256:_('Initializing the encoder failed(either vorbis or theora)'),
-        3*256:_('Could not open/configure sound card.'),
-        4*256:_('Xdamage extension not present.'),
-        5*256:_('Shared memory extension not present.'),
-        6*256:_('Xfixes extension not present.'),
-        7*256:_('XInitThreads failed.'),
-        8*256:_('No $DISPLAY environment variable and none specified as argument.'),
-        9*256:_('Cannot connect to Xserver.'),
-        10*256:_('Color depth is not 24bpp.'),
-        11*256:_('Improper window specification.'),
-        12*256:_('Cannot attach shared memory to proccess.'),
-        13*256:_('Cannot open file for writting.'),
-        14*256:_('Cannot load the Jack library (dlopen/dlsym error on libjack.so).'),
-        15*256:_('Cannot create new client.'),
-        16*256:_('Cannot activate client.'),
-        17*256:_('Port registration/connection failure.'),
-        11:_('Segmentation Fault')
-        }
-
-
     state=0#0 stopped,1 recording,2 paused
     rmdPid=None
     optionsOpen=[1]
@@ -175,19 +150,21 @@ class trayIcon(object):
             self.execargs.append("--full-shots")
         if self.parent.values[13] == 1:
             self.execargs.append("--no-shared")
-        if self.parent.values[5][0]>0  :
-            self.execargs.append('-x')
-            self.execargs.append('%d'%self.parent.values[5][0])
-        if self.parent.values[5][1]>0:
-            self.execargs.append('-y')
-            self.execargs.append('%d'%self.parent.values[5][1])
+        if self.parent.values[15]==1:
+            if self.parent.values[5][0]>0  :
+                self.execargs.append('-x')
+                self.execargs.append('%d'%self.parent.values[5][0])
+            if self.parent.values[5][1]>0:
+                self.execargs.append('-y')
+                self.execargs.append('%d'%self.parent.values[5][1])
         if self.parent.values[5][2]>0 and self.parent.values[5][3]>0:
             self.execargs.append('-width')
             self.execargs.append('%d'%(self.parent.values[5][2]-self.parent.values[5][0]))
             self.execargs.append('-height')
             self.execargs.append('%d'%(self.parent.values[5][3]-self.parent.values[5][1]))
-            for i in range(4):
-                self.parent.values[5][i]=-1
+            if(not self.parent.values[14]):
+                for i in range(4):
+                    self.parent.values[5][i]=-1
         if self.parent.values[6]>0:
             self.execargs.append('-delay')
             self.execargs.append('%d'%self.parent.values[6])
@@ -211,18 +188,22 @@ class trayIcon(object):
         self.execargs.append('%s'%self.parent.values[17])
         if self.parent.values[18] == 0:
             self.execargs.append('--on-the-fly-encoding')
-        if self.parent.values[19] == 0:
-            self.execargs.append('--zero-compression')
+        if self.parent.values[19] == 1:
+            self.execargs.append('--compress-cache')
         if self.parent.values[20] == True:
             self.execargs.append('--overwrite')
+        if self.parent.values[15] == 0:
+            self.execargs.append('--follow-mouse')
         if self.parent.values[22] == True:
             self.execargs.append('-use-jack')
             for i in self.parent.values[23]:
                 self.execargs.append(i)
+        if self.parent.values[26] != "":
+            for i in self.parent.values[26].split(" "):
+                if i!="":
+                    self.execargs.append(i)
         #print execargs
 
-
-
         self.childP=popen2.Popen3(self.execargs,"t")
         flags = fcntl.fcntl(self.childP.childerr, fcntl.F_GETFL)
         fcntl.fcntl(self.childP.childerr, fcntl.F_SETFL, flags | os.O_NONBLOCK)
@@ -249,10 +230,10 @@ class trayIcon(object):
         dialog = gtk.Dialog(title=None, parent=None, flags=0, buttons=None)
         label1=None
         try:
-            label1 = gtk.Label("\t\t"+_("Recording is finished.\nrecordMyDesktop has exited with status")+
-            ": %d\n"%(status)+_("Description")+":%s\n"%(self.exit_status[int(status)]))
+            label1 = gtk.Label("\t\t"+TrayIconStr['RecFinishedKnown']+
+            ": %d\n"%(status)+TrayIconStr['ErrDesc']+":%s\n"%(rmdErrStr[int(status)]))
         except:
-            label1 = gtk.Label("\t\t"+_("Recording is finished.\nrecordMyDesktop has exited with uknown\nerror code")+": %d \n"%(status))
+            label1 = gtk.Label("\t\t"+TrayIconStr['RecFinishedUnknown']+": %d \n"%(status))
         dialog.vbox.pack_start(label1, True, True, 0)
         label1.show()
         button = gtk.Button(label=None, stock=gtk.STOCK_OK)
